@@ -70,6 +70,8 @@ class FormArtist(NetworkArtist):
         self.reaction_tol = reactiontol
         self.reaction_scale = reactionscale
 
+        self.edge_width = edgewidth
+
         self.edge_text = self._edge_textlabel(edgetext)
         self.node_text = self._node_textlabel(nodetext)
 
@@ -78,6 +80,34 @@ class FormArtist(NetworkArtist):
         self.show_nodetext = show_nodetext
         self.show_edgetext = show_edgetext
 
+    @property
+    def edge_width(self):
+        return NetworkArtist.edge_width.fget(self)
+
+    @edge_width.setter
+    def edge_width(self, edgewidth):
+        NetworkArtist.edge_width.fset(self, edgewidth)
+
+        if self._edge_width:
+            return
+
+        low, high = edgewidth
+        edgewidth = dict()
+        forces = [fabs(self.network.edge_force(edge)) for edge in self.edges]
+        forcemin = min(forces)
+        forcemax = max(forces)
+
+        for edge in self.edges:
+            force = fabs(self.network.edge_force(edge))
+            try:
+                ratio = (force - forcemin) / (forcemax - forcemin)
+            except ZeroDivisionError:
+                ratio = 1.0
+            width = (1.0 - ratio) * low + ratio * high
+            edgewidth[edge] = width
+
+        self._edge_width = edgewidth
+
     def draw_nodes(self):
         """
         Draw the nodes of a form diagram.
@@ -97,7 +127,15 @@ class FormArtist(NetworkArtist):
         Draw the edges of a form diagram.
         """
         cmap = self.edge_statecolors
-        ec = {e: cmap[copysign(1.0, self.form.edge_attribute(e, "force") or 0.0)] for e in self.form.edges()}
+        ec = {}
+        for edge in self.form.edges():
+            force = self.form.edge_force(edge)
+            if force == 0.0:
+                color = cmap[0]
+            else:
+                color = cmap[copysign(1, force)]
+
+            ec[edge] = color
 
         return super(FormArtist, self).draw_edges(color=ec)
 
@@ -168,7 +206,7 @@ class FormArtist(NetworkArtist):
             if f_len < tol:
                 continue
 
-            start = self.form.node_xyz(node)
+            start = self.form.node_coordinates(node)
             end = add_vectors(start, f_vec_scaled)
 
             # shift
@@ -199,7 +237,7 @@ class FormArtist(NetworkArtist):
             A dictionary of text labels
         """
         def gkey_format(x):
-            return geometric_key(self.form.node_xyz(x), precision)
+            return geometric_key(self.form.node_coordinates(x), precision)
 
         def key_gkey_format(x):
             return "{}\n{}".format(x, gkey_format(x))
